@@ -85,7 +85,7 @@ class Scenario:
   def listen(self):
     if not self.init or self.nis:
       raise ScenarioNotStartedException
-    j = Server._decode_json(self._waits_for())
+    j = Scenario._decode_json(self._waits_for())
     if "sfinish" in j:
       if j["sfinish"] is True:
         raise ScenarioTerminatedException
