@@ -2,6 +2,8 @@ import json, socket
 
 class Server:
   def __init__(self, host, port):
+    self.host = host
+    self.port = port
     self.server_socket = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
     self.server_socket.bind((host if host is not None else socket.gethostname(), port))
     self.server_socket.listen()
